@@ -2,55 +2,53 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  *
  * TOra - An Oracle Toolkit for DBA's and developers
- * 
+ *
  * Shared/mixed copyright is held throughout files in this product
- * 
+ *
  * Portions Copyright (C) 2000-2001 Underscore AB
  * Portions Copyright (C) 2003-2005 Quest Software, Inc.
- * Portions Copyright (C) 2004-2009 Numerous Other Contributors
- * 
+ * Portions Copyright (C) 2004-2013 Numerous Other Contributors
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation;  only version 2 of
  * the License is valid for this program.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- * 
+ * along with this program as the file COPYING.txt; if not, please see
+ * http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt.
+ *
  *      As a special exception, you have permission to link this program
  *      with the Oracle Client libraries and distribute executables, as long
  *      as you follow the requirements of the GNU GPL in regard to all of the
  *      software in the executable aside from Oracle client libraries.
- * 
- *      Specifically you are not permitted to link this program with the
- *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
- *      And you are not permitted to distribute binaries compiled against
- *      these libraries. 
- * 
- *      You may link this product with any GPL'd Qt library.
- * 
+ *
  * All trademarks belong to their respective owners.
  *
  * END_COMMON_COPYRIGHT_HEADER */
 
-#include "utils.h"
-#include "toviewconnections.h"
-#include "tomain.h"
-#include "toconnectionmodel.h"
+#include "docklets/toviewconnections.h"
+#include "core/toconnectionmodel.h"
+#include "core/toconnection.h"
+#include "core/toconnectionregistry.h"
+#include "core/tooracleconst.h"
+#include "core/utils.h"
+#include "core/toglobalevent.h"
 
 #include <QHeaderView>
+#include <QTableView>
+#include <QSortFilterProxyModel>
+#include "main/tonewconnection.h"
 
 REGISTER_VIEW("Connection", toViewConnections);
 
-
 toViewConnections::toViewConnections(QWidget *parent,
-                                 Qt::WindowFlags flags)
+                                     toWFlags flags)
     : toDocklet(tr("Connections"), parent, flags)
 {
     setObjectName("Connections Docklet");
@@ -62,7 +60,7 @@ toViewConnections::toViewConnections(QWidget *parent,
     toNewConnection::connectionModel()->readConfig();
     TableView->setModel(Model);
 
-	TableView->horizontalHeader()->setStretchLastSection(true);
+    TableView->horizontalHeader()->setStretchLastSection(true);
     TableView->horizontalHeader()->setHighlightSections(false);
     TableView->verticalHeader()->setVisible(false);
     TableView->hideColumn(0);
@@ -94,8 +92,9 @@ QString toViewConnections::name() const
 }
 
 
-void toViewConnections::handleActivated(const QModelIndex &index) {
-    if(!index.isValid())
+void toViewConnections::handleActivated(const QModelIndex &index)
+{
+    if (!index.isValid())
         return;
 
     QModelIndex baseIndex = toNewConnection::proxyModel()->index(index.row(), 0);
@@ -106,10 +105,10 @@ void toViewConnections::handleActivated(const QModelIndex &index) {
     QString host     = opt.host;
     QString provider = opt.provider;
 
-    if(opt.port)
+    if (opt.port)
         host += ":" + QString::number(opt.port);
 
-    if(provider == toNewConnection::ORACLE_INSTANT)
+    if (provider == ORACLE_INSTANTCLIENT)
     {
         // create the rest of the connect string. this will work
         // without an ORACLE_HOME.
@@ -118,30 +117,22 @@ void toViewConnections::handleActivated(const QModelIndex &index) {
         host = "";
     }
 
-    if(opt.provider.startsWith("Oracle"))
+    if (opt.provider.startsWith("Oracle"))
         provider = "Oracle";
 
     // checks for existing connection
-    std::list<QString> con = toMainWidget()->connections();
-    for (std::list<QString>::iterator i = con.begin();i != con.end();i++)
+    QList<toConnection*> const& connections = toConnectionRegistrySing::Instance().connections();
+    foreach(toConnection * conn, connections)
     {
         try
         {
-            toConnection &conn = toMainWidget()->connection(*i);
-
-//             qDebug() << "user" << conn.user() << opt.username;
-//             qDebug() << "prov" << conn.provider() << provider;
-//             qDebug() << "host" << conn.host() << host;
-//             qDebug() << "db" << conn.database() << database;
-//             qDebug() << "schema" << conn.schema() << opt.schema;
-
-            if(conn.user() == opt.username &&
-               conn.provider() == provider &&
-               conn.host() == host &&
-               conn.database() == database &&
-               (opt.schema.isEmpty() || (conn.schema() == opt.schema)))
+            if (conn->user() == opt.username &&
+                    conn->provider() == provider &&
+                    conn->host() == host &&
+                    conn->database() == database &&
+                    (opt.schema.isEmpty() || (conn->defaultSchema() == opt.schema)))
             {
-                toMainWidget()->createDefault();
+                toGlobalEventSingle::Instance().createDefaultTool();
                 emit activated();
                 return;
             }
@@ -149,7 +140,8 @@ void toViewConnections::handleActivated(const QModelIndex &index) {
         catch (...) {}
     }
 
-    try {
+    try
+    {
         toConnection *retCon = new toConnection(
             provider,
             opt.username,
@@ -160,8 +152,8 @@ void toViewConnections::handleActivated(const QModelIndex &index) {
             opt.color,
             opt.options);
 
-        if(retCon)
-            toMainWidget()->addConnection(retCon, true);
+        if (retCon)
+            toGlobalEventSingle::Instance().addConnection(retCon, true);
         emit activated();
     }
     TOCATCH;
