@@ -2,39 +2,32 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  *
  * TOra - An Oracle Toolkit for DBA's and developers
- * 
+ *
  * Shared/mixed copyright is held throughout files in this product
- * 
+ *
  * Portions Copyright (C) 2000-2001 Underscore AB
  * Portions Copyright (C) 2003-2005 Quest Software, Inc.
- * Portions Copyright (C) 2004-2009 Numerous Other Contributors
- * 
+ * Portions Copyright (C) 2004-2013 Numerous Other Contributors
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation;  only version 2 of
  * the License is valid for this program.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- * 
+ * along with this program as the file COPYING.txt; if not, please see
+ * http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt.
+ *
  *      As a special exception, you have permission to link this program
  *      with the Oracle Client libraries and distribute executables, as long
  *      as you follow the requirements of the GNU GPL in regard to all of the
  *      software in the executable aside from Oracle client libraries.
- * 
- *      Specifically you are not permitted to link this program with the
- *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
- *      And you are not permitted to distribute binaries compiled against
- *      these libraries. 
- * 
- *      You may link this product with any GPL'd Qt library.
- * 
+ *
  * All trademarks belong to their respective owners.
  *
  * END_COMMON_COPYRIGHT_HEADER */
@@ -42,19 +35,19 @@
 #ifndef SQLDEVELOPER_H
 #define SQLDEVELOPER_H
 
-#include <QList>
+#include <QtCore/QList>
 
-#include "tonewconnection.h"
+#include "core/toconnectionoptions.h"
 
 namespace MigrateTool
 {
 
-/*! \brief Parse Oracle SQL Developer connection export file.
-Version 1.5 or later ("new" format) is supported only.
-OK, this code looks ugly but it's enough for "one time runners".
-\author Petr Vanek <petr@scribus.info>
-*/
-QMap<int,toConnectionOptions> sqlDeveloper(QWidget * parent = 0);
+    /*! \brief Parse Oracle SQL Developer connection export file.
+    Version 1.5 or later ("new" format) is supported only.
+    OK, this code looks ugly but it's enough for "one time runners".
+    \author Petr Vanek <petr@scribus.info>
+    */
+    QMap<int, toConnectionOptions> sqlDeveloper(QWidget * parent = 0);
 
 } // namespace
 
